# {{problem.name}}

Nhập vào $3$ số nguyên $B$, $P$, $M$. Hãy tính:

$$R = B^P \mod M$$

## Input

- Dòng đầu chứa số tự nhiên $T$ - số lượng các testcase
- $T$ dòng sau, mỗi dòng chứa $3$ số nguyên không âm $B$, $P$, $dM$.

## Constraints

- $0 ≤ B, P ≤ 2^{31} - 1$
- $1 ≤ M ≤ 46340$

## Output

$1$ số $R$ là kết quả phép tính $R = B^P \mod M$

## Sample input 1

```
3 18132 17
```

## Sample output 1

```
13
```

## Explanation 1

Giải thích cho test case 1
